@@ -36,7 +36,7 @@ import java.util.Set;
  * @author roland
  * @since Jun 18, 2009
  */
-public class SearchHandler extends RequestHandler {
+public class SearchHandler extends JsonRequestHandler {
 
     public SearchHandler(Restrictor pRestrictor) {
         super(pRestrictor);
@@ -49,7 +49,7 @@ public class SearchHandler extends RequestHandler {
 
     @Override
     public Object doHandleRequest(MBeanServer server, JmxRequest request)
-            throws InstanceNotFoundException, AttributeNotFoundException, ReflectionException, MBeanException {
+            throws InstanceNotFoundException, AttributeNotFoundException, MBeanException {
         Set<ObjectName> names = server.queryNames(request.getObjectName(),null);
         if (names == null || names.size() == 0) {
             throw new InstanceNotFoundException("No MBean with pattern " + request.getObjectNameAsString() + " found");
