@@ -33,19 +33,8 @@ JMX::Jmx4Perl::Config - Configuration file support for Jmx4Perl
     User = roland
     Password = test
     Product = JBoss
-    
-    # HTTP proxy for accessing the agent
-    <Proxy>
-      Url = http://proxy:8001
-      User = proxyuser
-      Password = ppaasswwdd
-    </Proxy>
-    # Target for running j4p in proxy mode
-    <Target>
-      Url       service:jmx:iiop://....
-      User      weblogic
-      Password  weblogic
-    </Target>       
+  # Proxy_User = ....
+  # Proxy_Password = ....
   </Server>
 
 =item Usage
@@ -62,51 +51,32 @@ JMX::Jmx4Perl::Config - Configuration file support for Jmx4Perl
 
 =over
 
-=item $cfg = JMX::Jmx4Perl::Config->new($file_or_hash)
+=item $cfg = JMX::Jmx4Perl::Config->new($file)
 
 Create a new configuration object with the given file name. If no file name 
 is given the configuration F<~/.j4p> is tried. If the file does not 
 exist, C<server_config_exists> will alway return C<false> and
 C<get_server_config> will always return C<undef>
 
-If a hash is given as argument, this hash is used to extract the server 
-information.
-
 =cut 
 
 sub new { 
     my $class = shift;
-    my $file_or_hash = shift;
+    my $file = shift;
+    $file = $ENV{HOME} . "/.j4p" unless $file;
     my $self = {};
-    my $config = undef;;
-    if (!ref($file_or_hash)) {
-        my $file = $file_or_hash ? $file_or_hash : $ENV{HOME} . "/.j4p";
-        if (-e $file) {
-            if ($HAS_CONFIG_GENERAL) {
-                local $SIG{__WARN__} = sub {};  # Keep Config::General silent
-                                                # when including things twice
-                $config = {
-                           new Config::General(-ConfigFile => $file,-LowerCaseNames => 1,
-                                               -UseApacheInclude => 1,-IncludeRelative => 1, -IncludeAgain => 0,
-                                               -IncludeGlob => 1, -IncludeDirectories => 1,  -CComments => 0)->getall
-                          };
-            } else {
-                warn "Configuration file $file found, but Config::General is not installed.\n" . 
-                  "Please install Config::General, for the moment we are ignoring the content of $file\n\n";
-            }
+    if (-e $file) {
+        if ($HAS_CONFIG_GENERAL) {
+            $self->{config} =           
+                 &_prepare_server_hash({
+                     new Config::General(-ConfigFile => $file,-LowerCaseNames => 1)->getall});
+        } else {
+            warn "Configuration file $file found, but Config::General is not installed.\n" . 
+              "Please install Config::General, for the moment we are ignoring the content of $file\n\n";
         }
-    } elsif (ref($file_or_hash) eq "HASH") {
-        $config = $file_or_hash;
     } else {
-        die "Invalid argument ",$file_or_hash;
+        $self->{config} = {};
     }
-    if ($config) {
-        $self->{server_config} = &_extract_servers($config);
-        $self->{servers} = [ values %{$self->{server_config}} ];
-        map { $self->{$_} = $config->{$_ } } grep { $_ ne "server" } keys %$config;
-        #print Dumper($self);
-    }
-
     bless $self,(ref($class) || $class);
     return $self;   
 }
@@ -135,35 +105,27 @@ if no such configuration exist.
 sub get_server_config {
     my $self = shift;
     my $name = shift || die "No server name given to reference to get config for";
-    return $self->{server_config} ? $self->{server_config}->{$name} : undef;
+    return $self->{config}->{$name};
 }
 
-=item $servers = $config->get_servers 
-
-Get an arrayref to all configured servers or an empty arrayref.
-
-=cut
-
-sub get_servers {
-    my $self = shift;
-    return $self->{servers} || [];
+sub _prepare_server_hash {
+    my $config = shift;
+    my $servers = &_get_configured_servers($config);
+    my $ret = {};
+    for my $server (@$servers) {
+        $ret->{$server->{name}} = $server;
+    };
+    return $ret;
 }
 
-sub _extract_servers {
+sub _get_configured_servers {
     my $config = shift;
     my $servers = $config->{server};
-    my $ret = {};
-    return $ret unless $servers;
-    if (ref($servers) eq "ARRAY") {
-        for my $s (@$servers) {
-            die "No name given for server config " . Dumper($s) . "\n" unless $s->{name};
-            $ret->{$s->{name}} = $s;
-        }
-        return $ret;
-    } elsif (ref($servers) eq "HASH") {
-        return $servers;
+    return [] unless $servers;
+    if (ref($servers) eq "HASH") {
+        return [ $servers ];
     } else {
-        die "Invalid configuration type ",ref($servers),"\n";        
+        return $servers;
     }
 }
 
