@@ -13,7 +13,7 @@ JMX::Jmx4Perl::Product::Jonas - Handler for Jonas
 
 =head1 DESCRIPTION
 
-This is the product handler support Jonas 4 (L<http://jonas.ow2.org/>)
+This is the product handler support Jonas 4 and 5 (L<http://jonas.ow2.org/>)
 
 =cut
 
@@ -54,7 +54,7 @@ sub init_aliases {
      attributes => 
    {
     #SERVER_ADDRESS => [ "jboss.system:type=ServerInfo", "HostAddress"],
-    SERVER_HOSTNAME => [ "jonas:name=jonas,type=ServerProxy", "HostName"],
+    #SERVER_HOSTNAME => [ "jonas:name=jonas,type=ServerProxy", "HostName"],
    },
      operations => 
    {
